==> radiant_0.1.71.tar.gz: radiant/inst/base/tools/app/tutorials.md <==
# Radiant - Business analytics using R and Shiny


## Installing Radiant

<iframe width="640" height="375" src="https://www.youtube.com/embed/AtB2SsmzBsk" frameborder="0" allowfullscreen></iframe>

## Starting and stopping

<iframe width="640" height="375" src="//www.youtube.com/embed/D71alRsGmBk" frameborder="0" allowfullscreen></iframe>

## Getting help

<iframe width="640" height="375" src="//www.youtube.com/embed/LFlCwapzAF0" frameborder="0" allowfullscreen></iframe>

## Getting data in and out

<iframe width="640" height="375" src="//www.youtube.com/embed/6AE1Wa74cJI" frameborder="0" allowfullscreen></iframe>

## Visualizing data

<iframe width="640" height="375" src="" frameborder="0" allowfullscreen></iframe>

## Generating predictions from regression and GLM

<iframe width="640" height="375" src="//www.youtube.com/embed/Xp1REGAewGU" frameborder="0" allowfullscreen></iframe>

## Creating a report

<iframe width="640" height="375" src="//www.youtube.com/embed/T_NQPfrWN-g" frameborder="0" allowfullscreen></iframe>

<!--
## Selecting variables for fast and efficient analysis
## View data in table form
## Visualize data
## Explore data
## Transform data
-->

## License


Radiant is licensed under the <a href="http://www.tldrlegal.com/l/AGPL3" target="\_blank">AGPLv3</a>. The documentation and videos on this site and the radiant help files are licensed under the creative commons attribution, non-commercial, share-alike license <a href="http://creativecommons.org/licenses/by-nc-sa/4.0/" target="_blank">CC-NC-SA</a>.

As a summary, the AGPLv3 license requires, attribution, including copyright and license information in copies of the software, stating changes if the code is modified, and disclosure of all source code. Details are in the COPYING file.

If you are interested in using Radiant please email me at radiant@rady.ucsd.edu

&copy; Vincent Nijs (2015) <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/" target="_blank"><img alt="Creative Commons License" style="border-width:0" src="imgs/80x15.png" /></a>

==> radiant_0.1.83.tar.gz: radiant/inst/base/tools/app/tutorials.md <==
# Radiant - Business analytics using R and Shiny


## Installing Radiant

<iframe width="640" height="375" src="https://www.youtube.com/embed/NEPSFiHH_dw" frameborder="0" allowfullscreen></iframe>

## Starting and stopping

<iframe width="640" height="375" src="https://www.youtube.com/embed/fC3EMC7N7_w" frameborder="0" allowfullscreen></iframe>

## Getting help

<iframe width="640" height="375" src="https://www.youtube.com/embed/O4w7eTmBh5M" frameborder="0" allowfullscreen></iframe>

## Getting data in and out

<iframe width="640" height="375" src="https://www.youtube.com/embed/ojNeFoMm4uQ" frameborder="0" allowfullscreen></iframe>

## Selecting variables for fast and efficient analysis

<iframe width="640" height="375" src="https://www.youtube.com/embed/-pWmlaRzbNk" frameborder="0" allowfullscreen></iframe>

<!--
## Visualizing data

<iframe width="640" height="375" src="" frameborder="0" allowfullscreen></iframe>

## Generating predictions from regression and GLM

<iframe width="640" height="375" src="//www.youtube.com/embed/Xp1REGAewGU" frameborder="0" allowfullscreen></iframe>

## Creating a report

<iframe width="640" height="375" src="//www.youtube.com/embed/T_NQPfrWN-g" frameborder="0" allowfullscreen></iframe>

## View data in table form
## Visualize data
## Explore data
## Transform data
-->

## License


Radiant is licensed under the <a href="http://www.tldrlegal.com/l/AGPL3" target="\_blank">AGPLv3</a>. The documentation and videos on this site and the radiant help files are licensed under the creative commons attribution, non-commercial, share-alike license <a href="http://creativecommons.org/licenses/by-nc-sa/4.0/" target="_blank">CC-NC-SA</a>.

As a summary, the AGPLv3 license requires, attribution, including copyright and license information in copies of the software, stating changes if the code is modified, and disclosure of all source code. Details are in the COPYING file.

If you are interested in using Radiant please email me at radiant@rady.ucsd.edu

&copy; Vincent Nijs (2015) <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/" target="_blank"><img alt="Creative Commons License" style="border-width:0" src="imgs/80x15.png" /></a>
